==> wp2-be-metrics-dm-1.0.0-20251219.092121-1-sources.jar: com/finconsgroup/itserr/marketplace/metrics/dm/controller/DiagnosticsController.java <==
package com.finconsgroup.itserr.marketplace.metrics.dm.controller;

import com.finconsgroup.itserr.marketplace.core.web.exception.WP2ResourceNotFoundException;
import com.finconsgroup.itserr.marketplace.metrics.dm.api.DiagnosticsApi;
import com.finconsgroup.itserr.marketplace.metrics.dm.dto.InputCreateMetricEventDto;
import com.finconsgroup.itserr.marketplace.metrics.dm.dto.MetricDtoType;
import com.finconsgroup.itserr.marketplace.metrics.dm.dto.OutputMetricEventDto;
import com.finconsgroup.itserr.marketplace.metrics.dm.dto.OutputMetricEventRefDto;
import com.finconsgroup.itserr.marketplace.metrics.dm.dto.OutputMetricsInterestWeightsConfigurationDto;
import com.finconsgroup.itserr.marketplace.metrics.dm.service.ConfigService;
import com.finconsgroup.itserr.marketplace.metrics.dm.service.MetricEventService;
import com.finconsgroup.itserr.marketplace.metrics.dm.service.MetricService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.core.LoggerContext;
import org.apache.logging.log4j.core.appender.RollingFileAppender;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.FileSystemResource;
import org.springframework.core.io.Resource;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RestController;

import java.io.File;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.util.UUID;

/**
 * REST controller class for handling debugging/analysis related API requests.
 *
 * <p>Implements the {@link DiagnosticsApi} interface.</p>
 */
@Slf4j
@RestController
@RequiredArgsConstructor
public class DiagnosticsController implements DiagnosticsApi {

    /** The name of the RollingFile Log4j2 component used to retrieve log file name. */
    @Value("${log.log4j2-rolling-file-name}")
    private String log4j2RollingFileName;

    /** A service that handles the business logic for MetricEvents. */
    private final MetricEventService metricEventService;
    /** A service that handles the business logic for metrics. */
    private final MetricService metricService;
    /** Service for handling business logic related to metrics configurations. */
    private final ConfigService configService;

    @Override
    public ResponseEntity<Resource> downloadLogs() {
        log.debug("call to DiagnosticsController - downloadLogs");
        Path filePath = Paths.get(getLogFilePathFromLog4j2());
        log.debug("Trying to retrieve log file from: {}", filePath);
        File logFile = filePath.toFile();
        if (!logFile.exists() || !logFile.isFile()) {
            throw new WP2ResourceNotFoundException("Log file not found: %s".formatted(logFile.getAbsolutePath()));
        }
        Resource resource = new FileSystemResource(logFile);
        return ResponseEntity.ok()
                .header(HttpHeaders.CONTENT_DISPOSITION, getContentDispositionHeaderValue(logFile.getName()))
                .contentType(MediaType.APPLICATION_OCTET_STREAM)
                .body(resource);
    }

    @Override
    public OutputMetricEventDto createMetricEvent(
            MetricDtoType metric,
            InputCreateMetricEventDto inputCreateMetricEventDto) {
        return metricEventService.create(metric, inputCreateMetricEventDto);
    }

    @Override
    public Page<OutputMetricEventRefDto> findAll(
            MetricDtoType metric,
            int pageNumber,
            int pageSize,
            String sort,
            Sort.Direction direction) {
        final Pageable pageable = PageRequest.of(pageNumber, pageSize, direction, sort);
        return metricEventService.findAll(metric, pageable);
    }

    @Override
    public OutputMetricEventDto findById(
            MetricDtoType metric,
            UUID metricEventId) {
        return metricEventService.findById(metric, metricEventId);
    }

    @Override
    public ResponseEntity<Void> updateMetrics(final boolean sync) {
        metricService.update(sync);
        return ResponseEntity
                .status(sync ? HttpStatus.NO_CONTENT : HttpStatus.ACCEPTED)
                .build();
    }

    @Override
    public OutputMetricsInterestWeightsConfigurationDto getInterestWeights() {
        return configService.getMetricsInterestWeightsConfiguration();
    }

    // private

    private String getLogFilePathFromLog4j2() {
        LoggerContext context = (LoggerContext) LogManager.getContext(false);
        RollingFileAppender appender = context.getConfiguration().getAppender(log4j2RollingFileName);
        return appender.getFileName();
    }

    private static String getContentDispositionHeaderValue(String fileName) {
        return "attachment; filename=\"%s\"".formatted(fileName);
    }

}

==> wp2-be-metrics-dm-1.2.0-sources.jar: com/finconsgroup/itserr/marketplace/metrics/dm/controller/DiagnosticsController.java <==
package com.finconsgroup.itserr.marketplace.metrics.dm.controller;

import com.finconsgroup.itserr.marketplace.core.web.exception.WP2ResourceNotFoundException;
import com.finconsgroup.itserr.marketplace.metrics.dm.api.DiagnosticsApi;
import com.finconsgroup.itserr.marketplace.metrics.dm.dto.InputCreateMetricEventDto;
import com.finconsgroup.itserr.marketplace.metrics.dm.dto.MetricDtoType;
import com.finconsgroup.itserr.marketplace.metrics.dm.dto.OutputMetricEventDto;
import com.finconsgroup.itserr.marketplace.metrics.dm.dto.OutputMetricEventRefDto;
import com.finconsgroup.itserr.marketplace.metrics.dm.dto.OutputMetricsInterestWeightsConfigurationDto;
import com.finconsgroup.itserr.marketplace.metrics.dm.exception.MetricEventConflictException;
import com.finconsgroup.itserr.marketplace.metrics.dm.service.ConfigService;
import com.finconsgroup.itserr.marketplace.metrics.dm.service.MetricEventService;
import com.finconsgroup.itserr.marketplace.metrics.dm.service.MetricService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.core.LoggerContext;
import org.apache.logging.log4j.core.appender.RollingFileAppender;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.FileSystemResource;
import org.springframework.core.io.Resource;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RestController;

import java.io.File;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.time.LocalDate;
import java.time.LocalTime;
import java.time.ZoneId;
import java.time.ZonedDateTime;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import java.util.UUID;
import java.util.stream.IntStream;

/**
 * REST controller class for handling debugging/analysis related API requests.
 *
 * <p>Implements the {@link DiagnosticsApi} interface.</p>
 */
@Slf4j
@RestController
@RequiredArgsConstructor
public class DiagnosticsController implements DiagnosticsApi {

    /** The name of the RollingFile Log4j2 component used to retrieve log file name. */
    @Value("${log.log4j2-rolling-file-name}")
    private String log4j2RollingFileName;

    /** A service that handles the business logic for MetricEvents. */
    private final MetricEventService metricEventService;
    /** A service that handles the business logic for metrics. */
    private final MetricService metricService;
    /** Service for handling business logic related to metrics configurations. */
    private final ConfigService configService;

    @Override
    public ResponseEntity<Resource> downloadLogs() {
        log.debug("call to DiagnosticsController - downloadLogs");
        Path filePath = Paths.get(getLogFilePathFromLog4j2());
        log.debug("Trying to retrieve log file from: {}", filePath);
        File logFile = filePath.toFile();
        if (!logFile.exists() || !logFile.isFile()) {
            throw new WP2ResourceNotFoundException("Log file not found: %s".formatted(logFile.getAbsolutePath()));
        }
        Resource resource = new FileSystemResource(logFile);
        return ResponseEntity.ok()
                .header(HttpHeaders.CONTENT_DISPOSITION, getContentDispositionHeaderValue(logFile.getName()))
                .contentType(MediaType.APPLICATION_OCTET_STREAM)
                .body(resource);
    }

    @Override
    public OutputMetricEventDto createMetricEvent(
            MetricDtoType metric,
            InputCreateMetricEventDto inputCreateMetricEventDto) {
        return metricEventService.create(metric, inputCreateMetricEventDto);
    }

    @Override
    public Page<OutputMetricEventRefDto> findAll(
            MetricDtoType metric,
            int pageNumber,
            int pageSize,
            String sort,
            Sort.Direction direction) {
        final Pageable pageable = PageRequest.of(pageNumber, pageSize, direction, sort);
        return metricEventService.findAll(metric, pageable);
    }

    @Override
    public OutputMetricEventDto findById(
            MetricDtoType metric,
            UUID metricEventId) {
        return metricEventService.findById(metric, metricEventId);
    }

    @Override
    public ResponseEntity<Void> updateMetrics(final boolean sync) {
        metricService.update(sync);
        return ResponseEntity
                .status(sync ? HttpStatus.NO_CONTENT : HttpStatus.ACCEPTED)
                .build();
    }

    @Override
    public OutputMetricsInterestWeightsConfigurationDto getInterestWeights() {
        return configService.getMetricsInterestWeightsConfiguration();
    }

    @Override
    public Map<String, Object> createReportMetricEvents(LocalDate fromDate,
                                                        LocalDate toDate,
                                                        Set<String> eventAuthorIds,
                                                        int resourceCount,
                                                        Set<String> resourceIds) {
        int metricsEventCount = 0;

        if (resourceCount > 0) {
            resourceIds = new HashSet<>(resourceIds);
            IntStream.range(resourceIds.size(), resourceCount).mapToObj(i -> UUID.randomUUID().toString()).forEach(resourceIds::add);
        }

        for (String resourceId : resourceIds) {
            LocalDate eventDate = fromDate;
            while (toDate.isAfter(eventDate)) {
                for (String eventAuthorId : eventAuthorIds) {
                    for (MetricDtoType metricDtoType : MetricDtoType.values()) {
                        try {
                            metricEventService.create(
                                    metricDtoType,
                                    InputCreateMetricEventDto.builder()
                                            .eventTime(ZonedDateTime.of(eventDate, LocalTime.now(), ZoneId.of("UTC")))
                                            .resourceId(resourceId)
                                            .eventAuthor(eventAuthorId)
                                            .build());
                            metricsEventCount++;
                        } catch (MetricEventConflictException e) {
                            log.debug("Metric event already exists for the combination");
                        }
                    }
                }
                eventDate = eventDate.plusDays(1);
            }
        }

        return Map.of("count", metricsEventCount);
    }

    // private

    private String getLogFilePathFromLog4j2() {
        LoggerContext context = (LoggerContext) LogManager.getContext(false);
        RollingFileAppender appender = context.getConfiguration().getAppender(log4j2RollingFileName);
        return appender.getFileName();
    }

    private static String getContentDispositionHeaderValue(String fileName) {
        return "attachment; filename=\"%s\"".formatted(fileName);
    }

}
